"""Import functions
"""
import argparse
import logging
import os
import re
from typing import List, Tuple

_logger = logging.getLogger(__name__)


def add_importing_file_parsing(parser: argparse.ArgumentParser):
    # TODO indicate that either a file or a directory is required
    parser.add_argument("-f", "--file", help="CSV to import", action="append")
    parser.add_argument(
        "--directory", help="Directory of CSV files to import", action="append"
    )


def extract_info_from_parsed(nmspc) -> List[Tuple[str, str, str]]:
    return extract_info_from_filename(nmspc.file, nmspc.directory)


def extract_info_from_filename(
    files, directories
) -> List[Tuple[str, str, str]]:
    """from filename or directories, extract model and lang

    :param files:
    :param directories:
    :return: list of model, filename, lang
    """
    model_filenames: List[Tuple[str, str, str]] = list()
    # files need to be named according to the following regexp
    pattern = re.compile(
        r"(?P<path>.*/)"
        r"(?:[\d\s\w_-]*\s)?"
        r"(?P<model>[\w.]+?)"
        r"(?:@(?P<lang>\w{2,3}(?:@latin|_\w{2})))?"
        r".csv"
    )
    file_list = list()
    if files:
        file_list.extend(files)
    if directories:
        for directory in directories:
            for root, subdirectories, files in os.walk(directory):
                file_list.extend(os.path.join(root, f) for f in sorted(files))
    for filename in file_list:
        _logger.debug("%s to import", filename)
        result = pattern.fullmatch(filename)
        if result:
            model = result.group("model")
            lang = result.group("lang")
            model_filenames.append((model, filename, lang))
        else:
            _logger.warning('Unrecognized file name "%s", ignored', filename)
    return model_filenames
